# UpdateOrganisationFpnDetailsRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authorised_officer_name** | **str** |  | 
**payment_methods** | [**list[PaymentMethod]**](PaymentMethod.md) |  | [optional] 
**authorised_officer_contact_details** | **str** |  | [optional] 
**authorised_officer_address** | **str** |  | [optional] 
**representations_contact_details** | **str** |  | [optional] 
**representations_contact_address** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

